diff artifacts/src/main/java/org/dive4elements/river/exports/FlowVelocityGenerator.java @ 5867:59ff03ff48f1

River artifacts: Renamed FLYSArtifact(Collection) to D4EArtifact(Collection).
author Sascha L. Teichmann <teichmann@intevation.de>
date Sun, 28 Apr 2013 15:23:01 +0200
parents 73da40528cf2
children af13ceeba52a
line wrap: on
line diff
--- a/artifacts/src/main/java/org/dive4elements/river/exports/FlowVelocityGenerator.java	Sun Apr 28 15:14:30 2013 +0200
+++ b/artifacts/src/main/java/org/dive4elements/river/exports/FlowVelocityGenerator.java	Sun Apr 28 15:23:01 2013 +0200
@@ -19,7 +19,7 @@
 import org.dive4elements.artifactdatabase.state.ArtifactAndFacet;
 import org.dive4elements.artifactdatabase.state.Facet;
 
-import org.dive4elements.river.artifacts.FLYSArtifact;
+import org.dive4elements.river.artifacts.D4EArtifact;
 
 import org.dive4elements.river.artifacts.access.FlowVelocityAccess;
 import org.dive4elements.river.artifacts.model.FacetTypes;
@@ -142,7 +142,7 @@
      */
     @Override
     protected String getDefaultXAxisLabel() {
-        FLYSArtifact flys = (FLYSArtifact) master;
+        D4EArtifact flys = (D4EArtifact) master;
 
         return msg(
             I18N_XAXIS_LABEL,
@@ -239,13 +239,13 @@
             context.putContextValue("endkm", getXBounds(0).getUpper());
         }
         else if (getXBounds(0) == null && getDomainAxisRange() == null) {
-            FLYSArtifact artifact = (FLYSArtifact)artifactAndFacet.getArtifact();
+            D4EArtifact artifact = (D4EArtifact)artifactAndFacet.getArtifact();
             FlowVelocityAccess access = new FlowVelocityAccess(artifact, context);
             context.putContextValue("startkm", access.getLowerKM());
             context.putContextValue("endkm", access.getUpperKM());
         }
         else if (getXBounds(0) == null && getDomainAxisRange() != null){
-            FLYSArtifact artifact = (FLYSArtifact)artifactAndFacet.getArtifact();
+            D4EArtifact artifact = (D4EArtifact)artifactAndFacet.getArtifact();
             FlowVelocityAccess access = new FlowVelocityAccess(artifact, context);
             Bounds b = new DoubleBounds(access.getLowerKM(), access.getUpperKM());
             Bounds bounds =
@@ -408,7 +408,7 @@
      *
      * @param data A FlowVelocityData object
      * @param aandf The facet. This facet does NOT support any data objects. Use
      * FLYSArtifact.getNativeFacet() instead to retrieve a Facet which supports
      * data.
      * @param theme The theme that contains styling information.
      * @param visible The visibility of the curve.
@@ -478,7 +478,7 @@
     /**
      * @param data A FlowVelocityData object
      * @param aandf The facet. This facet does NOT support any data objects. Use
      * FLYSArtifact.getNativeFacet() instead to retrieve a Facet which supports
      * data.
      * @param theme The theme that contains styling information.
      * @param visible The visibility of the curve.
@@ -501,7 +501,7 @@
     /**
      * @param data A FlowVelocityData object
      * @param aandf The facet. This facet does NOT support any data objects. Use
      * FLYSArtifact.getNativeFacet() instead to retrieve a Facet which supports
      * data.
      * @param theme The theme that contains styling information.
      * @param visible The visibility of the curve.
@@ -408,7 +408,7 @@
      * @param data A FlowVelocityData object
      * @param aandf The facet. This facet does NOT support any data objects. Use
-     * FLYSArtifact.getNativeFacet() instead to retrieve a Facet which supports
+     * D4EArtifact.getNativeFacet() instead to retrieve a Facet which supports
      * data.
      * @param theme The theme that contains styling information.
@@ -478,7 +478,7 @@
      * @param data A FlowVelocityData object
      * @param aandf The facet. This facet does NOT support any data objects. Use
-     * FLYSArtifact.getNativeFacet() instead to retrieve a Facet which supports
+     * D4EArtifact.getNativeFacet() instead to retrieve a Facet which supports
      * data.
      * @param theme The theme that contains styling information.
@@ -501,7 +501,7 @@
      * @param data A FlowVelocityData object
      * @param aandf The facet. This facet does NOT support any data objects. Use
-     * FLYSArtifact.getNativeFacet() instead to retrieve a Facet which supports
+     * D4EArtifact.getNativeFacet() instead to retrieve a Facet which supports
      * data.
      * @param theme The theme that contains styling information.

http://dive4elements.wald.intevation.org